cli

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2026 License: MIT Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(args []string) error

Types

type AnalyzeOptions

type AnalyzeOptions struct {
	ConfigPath     string
	ExplicitConfig bool // true when --config was explicitly passed
	Tau            float64
	SampleSize     int
	Workers        int
	Recursive      bool
	MaxDepth       int
	Format         string
	PressureMode   string
	ActiveDays     int
	DomainFilter   string
	Verbose        bool
	NoCache        bool
	PerRepo        bool
}

AnalyzeOptions holds CLI flags for the analysis pipeline.

type DomainResults

type DomainResults struct {
	Domain    domain.Domain
	Results   []scorer.Result
	Risks     []metric.ModuleRisk
	RepoCount int
	PerRepo   []RepoResult // per-repo breakdown (only when --per-repo is set)

	// Module Science Phase 1: direct structural measurement
	Cochange  []metric.CochangeResult  // per-repo co-change coupling (DSM)
	Ownership []metric.ModuleOwnership // accumulated ownership fragmentation

	// Module Science Phase 2: 3-axis module topology
	ModuleScores []scorer.ModuleScore
}

DomainResults holds scored results for a single domain.

func RunAnalyzePipeline

func RunAnalyzePipeline(opts AnalyzeOptions, paths []string) ([]DomainResults, *config.Config, error)

RunAnalyzePipeline runs the full analysis pipeline and returns per-domain results. This is the shared core used by both `eis analyze` and `eis team`.

type RepoResult

type RepoResult struct {
	RepoName string
	Domain   domain.Domain
	Results  []scorer.Result
}

RepoResult holds scored results for a single repository.

Jump to