cache

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package cache re-exports the internal cache types for external consumers.

Index

Constants

This section is empty.

Variables

var (
	// New creates a cache store with the default directory (~/.eis/cache).
	New = cache.New

	// NewWithDir creates a cache store with a custom base directory.
	NewWithDir = cache.NewWithDir

	// BlameKey returns the cache key for ConcurrentBlameFiles results.
	BlameKey = cache.BlameKey

	// LogKey returns the cache key for ParseLog results.
	LogKey = cache.LogKey

	// MergeLogKey returns the cache key for ParseMergeCommits results.
	MergeLogKey = cache.MergeLogKey

	// DebtKey returns the cache key for CalcDebt results.
	DebtKey = cache.DebtKey

	// Clear removes cache for a specific repo, or all caches if repoPath is empty.
	Clear = cache.Clear

	// CacheSize returns the total size of cache in bytes.
	CacheSize = cache.CacheSize
)

Functions

This section is empty.

Types

type Store

type Store = cache.Store

Store is a disk-based cache for expensive git operations.

Jump to